@@ -67,6 +67,10 @@ class WorkerController(Controller):
         self._debug('Stop acceptor %r.', name)
         self.acceptors.stop_by_name(name)
 
+    def get_stack(self):
+        """Return currently running methods."""
+        return self.app.request_stack.to_dict()
+
     def get_counters(self):
         """Return counters here."""
         return self.app.thriftworker.counters.to_dict()
